function traces = gen_signals_amc2(modname, snr, nsamples, nlen, phaseoffset)

if ~exist('phaseoffset', 'var')
  phaseoffset = 0;
end

assert (phaseoffset >= 0 | phaseoffset == -1)
if phaseoffset == -1
  random_po = rand(nsamples,1);
else
  random_po = [];
end


Fs = 2000;

traces = [];

for n = 1:nsamples

  M = get_modulation_order(modname);

  symbols = [0:M-1];
  data = repmat(symbols', [ceil(Fs/length(symbols)) 1]);
  data = data(randperm(length(data)));

  if isempty(random_po)
    txSig = gen_symbols_amc2(modname, -1, data, false, phaseoffset);
  else
    txSig = gen_symbols_amc2(modname, -1, data, false, random_po(n)*pi);
  end

  if (snr < 100)
    y1 = awgn(txSig,snr,'measured');
  else
    y1 = txSig;
  end

  nsize = size(y1);

  a = 1;
  b = max([nsize(1) - nlen, 1]);
  r = randi([a b],1,5);

  assert (r(1)+nlen-1<=nsize(1));
  sliced = y1(r(1):r(1)+nlen-1);

  if isempty(traces)
    traces = sliced.';
  else
    traces = [traces; sliced.'];
  end

end

nsize = size(traces);

assert (nsize(1) == nsamples);
assert (nsize(2) == nlen);

end